Learn R Programming

fasster (version 0.1.0.9000)

autoplot.FASSTER: Create a complete ggplot appropriate to a particular data type

Description

autoplot uses ggplot2 to draw a particular plot for an object of a particular class in a single command. This defines the S3 generic that other classes and packages can extend.

Usage

# S3 method for FASSTER
autoplot(object, range.bars = FALSE, ...)

Arguments

object

an object, whose class will determine the behaviour of autoplot

range.bars

Logical indicating if each plot should have a bar at its right side representing relative size. If NULL, automatic selection takes place.

...

other arguments passed to specific methods

Value

a ggplot object

See Also

autolayer(), ggplot() and fortify()