Learn R Programming

fasster (version 0.2.0)

fasster-package: fasster: Fast Additive Switching of Seasonality, Trend, and Exogenous Regressors

Description

logo

Implementation of the FASSTER (Forecasting with Additive Switching of Seasonality, Trend, and Exogenous Regressors) model for forecasting time series with multiple seasonal patterns. The model combines state space methodology with a switching component in the observation equation to allow flexible modeling of complex seasonal patterns, including time-varying effects and multiple seasonalities.

Arguments

Author

Maintainer: Mitchell O'Hara-Wild mail@mitchelloharawild.com

Authors:

  • Rob Hyndman [thesis advisor]

See Also