Learn R Programming

fasster (version 0.2.0)

glance.FASSTER: Glance at a FASSTER model

Description

Constructs a single-row summary of the model's goodness-of-fit statistics. This method follows the broom package conventions and is used by fabletools to provide model selection metrics.

Usage

# S3 method for FASSTER
glance(x, ...)

Value

A one-row tibble containing:

sigma2

The estimated observation variance (V). If the model has multivariate observations, this is a list containing the variance matrix.

log_lik

The log-likelihood of the model.

AIC

Akaike Information Criterion.

AICc

Corrected AIC for small sample sizes.

BIC

Bayesian Information Criterion.

Arguments

x

A FASSTER model object.

...

Additional arguments (currently unused).

Examples

Run this code
library(tsibble)
fit <- as_tsibble(mdeaths) |>
  model(FASSTER(value ~ trend(1) + fourier(12)))

# Get model fit statistics
glance(fit)

Run the code above in your browser using DataLab