autoplot uses ggplot2 to draw a particular plot for an object of a
particular class in a single command. This defines the S3 generic that
other classes and packages can extend.
# S3 method for FASSTER
autoplot(object, range.bars = FALSE, ...)an object, whose class will determine the behaviour of autoplot
Logical indicating if each plot should have a bar at its right side representing relative size. If NULL, automatic selection takes place.
other arguments passed to specific methods
a ggplot object
autolayer(), ggplot() and fortify()