Constructs a single-row summary of the model's goodness-of-fit statistics.
This method follows the broom package conventions and is used by fabletools
to provide model selection metrics.
Usage
# S3 method for FASSTER
glance(x, ...)
Value
A one-row tibble containing:
sigma2
The estimated observation variance (V). If the model has
multivariate observations, this is a list containing the variance matrix.