Obtains the mean and variance of the estimated initial states from a FASSTER
model. Values in the estimate column are contains the mean, and the
std.error column contains the standard deviation of the initial states.
# S3 method for FASSTER
tidy(x, ...)A tibble with three columns:
The name of each state variable in the model.
The mean of the estimated initial state for each term.
The standard deviation of the estimated initial state for each term.
An object containing a FASSTER model.
Unused.